var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useRef, useState } from 'react';
import { VIEWS, } from 'pasubot-auth-ui-shared';
import { Anchor, Button, Container, Input, Label, Message, } from './../../UI/index.js';
function EmailAuth({ authView = 'sign_in', defaultEmail = '', defaultPassword = '', setAuthView = () => { }, setDefaultEmail = (email) => { }, setDefaultPassword = (password) => { }, supabaseClient, showLinks = false, redirectTo, additionalData, magicLink, i18n, appearance, passwordLimit = false, children, }) {
    var _a, _b, _c, _d;
    const isMounted = useRef(true);
    const [email, setEmail] = useState(defaultEmail);
    const [password, setPassword] = useState(defaultPassword);
    const [error, setError] = useState('');
    const [loading, setLoading] = useState(false);
    const [message, setMessage] = useState('');
    useEffect(() => {
        isMounted.current = true;
        setEmail(defaultEmail);
        setPassword(defaultPassword);
        return () => {
            isMounted.current = false;
        };
    }, [authView]);
    const handleSubmit = (e) => __awaiter(this, void 0, void 0, function* () {
        var _e;
        e.preventDefault();
        setError('');
        setLoading(true);
        switch (authView) {
            case 'sign_in':
                const { error: signInError } = yield supabaseClient.auth.signInWithPassword({
                    email,
                    password,
                });
                if (signInError)
                    setError(signInError.message);
                break;
            case 'sign_up':
                if (passwordLimit && password.length > 72) {
                    setError('Password exceeds maxmium length of 72 characters');
                    return;
                }
                let options = {
                    emailRedirectTo: redirectTo,
                };
                if (additionalData) {
                    options.data = additionalData;
                }
                const { data: { user: signUpUser, session: signUpSession }, error: signUpError, } = yield supabaseClient.auth.signUp({
                    email,
                    password,
                    options,
                });
                if (signUpError)
                    setError(signUpError.message);
                // Check if session is null -> email confirmation setting is turned on
                else if (signUpUser && !signUpSession)
                    setMessage((_e = i18n === null || i18n === void 0 ? void 0 : i18n.sign_up) === null || _e === void 0 ? void 0 : _e.confirmation_text);
                break;
        }
        /*
         * it is possible the auth component may have been unmounted at this point
         * check if component is mounted before setting a useState
         */
        if (isMounted.current)
            setLoading(false);
    });
    const handleViewChange = (newView) => {
        setDefaultEmail(email);
        setDefaultPassword(password);
        setAuthView(newView);
    };
    const labels = i18n === null || i18n === void 0 ? void 0 : i18n[authView];
    return (_jsxs("form", Object.assign({ id: authView === 'sign_in' ? `auth-sign-in` : `auth-sign-up`, onSubmit: handleSubmit, autoComplete: 'on', style: { width: '100%' } }, { children: [_jsxs(Container, Object.assign({ direction: "vertical", gap: "large", appearance: appearance }, { children: [_jsxs(Container, Object.assign({ direction: "vertical", gap: "large", appearance: appearance }, { children: [_jsxs("div", { children: [_jsx(Label, Object.assign({ htmlFor: "email", appearance: appearance }, { children: labels === null || labels === void 0 ? void 0 : labels.email_label })), _jsx(Input, { id: "email", type: "email", name: "email", placeholder: labels === null || labels === void 0 ? void 0 : labels.email_input_placeholder, defaultValue: email, onChange: (e) => setEmail(e.target.value), autoComplete: "email", appearance: appearance })] }), _jsxs("div", { children: [_jsx(Label, Object.assign({ htmlFor: "password", appearance: appearance }, { children: labels === null || labels === void 0 ? void 0 : labels.password_label })), _jsx(Input, { id: "password", type: "password", name: "password", placeholder: labels === null || labels === void 0 ? void 0 : labels.password_input_placeholder, defaultValue: password, onChange: (e) => setPassword(e.target.value), autoComplete: authView === 'sign_in' ? 'current-password' : 'new-password', appearance: appearance })] }), children] })), _jsx(Button, Object.assign({ type: "submit", color: "primary", loading: loading, appearance: appearance }, { children: loading ? labels === null || labels === void 0 ? void 0 : labels.loading_button_label : labels === null || labels === void 0 ? void 0 : labels.button_label })), showLinks && (_jsxs(Container, Object.assign({ direction: "vertical", gap: "small", appearance: appearance }, { children: [authView === VIEWS.SIGN_IN && magicLink && (_jsx(Anchor, Object.assign({ href: "#auth-magic-link", onClick: (e) => {
                                    e.preventDefault();
                                    setAuthView(VIEWS.MAGIC_LINK);
                                }, appearance: appearance }, { children: (_a = i18n === null || i18n === void 0 ? void 0 : i18n.magic_link) === null || _a === void 0 ? void 0 : _a.link_text }))), authView === VIEWS.SIGN_IN && (_jsx(Anchor, Object.assign({ href: "#auth-forgot-password", onClick: (e) => {
                                    e.preventDefault();
                                    setAuthView(VIEWS.FORGOTTEN_PASSWORD);
                                }, appearance: appearance }, { children: (_b = i18n === null || i18n === void 0 ? void 0 : i18n.forgotten_password) === null || _b === void 0 ? void 0 : _b.link_text }))), authView === VIEWS.SIGN_IN ? (_jsx(Anchor, Object.assign({ href: "#auth-sign-up", onClick: (e) => {
                                    e.preventDefault();
                                    handleViewChange(VIEWS.SIGN_UP);
                                }, appearance: appearance }, { children: (_c = i18n === null || i18n === void 0 ? void 0 : i18n.sign_up) === null || _c === void 0 ? void 0 : _c.link_text }))) : (_jsx(Anchor, Object.assign({ href: "#auth-sign-in", onClick: (e) => {
                                    e.preventDefault();
                                    handleViewChange(VIEWS.SIGN_IN);
                                }, appearance: appearance }, { children: (_d = i18n === null || i18n === void 0 ? void 0 : i18n.sign_in) === null || _d === void 0 ? void 0 : _d.link_text })))] })))] })), message && _jsx(Message, Object.assign({ appearance: appearance }, { children: message })), error && (_jsx(Message, Object.assign({ color: "danger", appearance: appearance }, { children: error })))] })));
}
export { EmailAuth };
